@@ -1,5 +1,5 @@
-crew_test("throttling happens at the right times", {
-  x <- crew_throttle(seconds_interval = 4)
+crew_test("throttle$poll() returns the right values at the right times", {
+  x <- crew_throttle(seconds_max = 4, seconds_min = 4, seconds_start = 4)
   throttled <- 0L
   start <- proc.time()["elapsed"]
   while (proc.time()["elapsed"] - start < 10) {
