@@ -5,6 +5,7 @@ crew_test("relay start, terminate, validate", {
   x$start()
   expect_silent(x$validate())
   expect_true(inherits(x$condition, "conditionVariable"))
+  expect_true(inherits(x$throttle, "crew_class_throttle"))
   x$terminate()
   expect_silent(x$validate())
   expect_null(x$condition)
@@ -18,15 +19,14 @@ crew_test("relay and waiting", {
   expect_silent(x$validate())
   nanonext::cv_signal(x$from)
   nanonext::msleep(250)
-  throttle <- crew_throttle()
   expect_equal(nanonext::cv_value(x$from), 1L)
   expect_equal(nanonext::cv_value(x$condition), 1L)
   expect_equal(nanonext::cv_value(x$to), 1L)
-  expect_true(x$wait(throttle = throttle))
+  expect_true(x$wait())
   expect_equal(nanonext::cv_value(x$from), 1L)
   expect_equal(nanonext::cv_value(x$condition), 0L)
   expect_equal(nanonext::cv_value(x$to), 1L)
-  expect_false(x$wait(throttle = throttle))
+  expect_false(x$wait())
   expect_equal(nanonext::cv_value(x$from), 1L)
   expect_equal(nanonext::cv_value(x$condition), 0L)
   expect_equal(nanonext::cv_value(x$to), 1L)
